==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/BinaryBuildSourceFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class BinaryBuildSourceFluentImpl<A extends io.fabric8.openshift.api.model.BinaryBuildSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.BinaryBuildSourceFluent<A>{
  public BinaryBuildSourceFluentImpl() {
  }
  public BinaryBuildSourceFluentImpl(io.fabric8.openshift.api.model.BinaryBuildSource instance) {
    this.withAsFile(instance.getAsFile()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String asFile;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getAsFile() {
    return this.asFile;
  }
  public A withAsFile(java.lang.String asFile) {
    this.asFile=asFile; return (A) this;
  }
  public java.lang.Boolean hasAsFile() {
    return this.asFile != null;
  }
  
  /**
   * Method is deprecated. use withAsFile instead.
   */
  @java.lang.Deprecated
  public A withNewAsFile(java.lang.String arg0) {
    return (A)withAsFile(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BinaryBuildSourceFluentImpl that = (BinaryBuildSourceFluentImpl) o;
    if (asFile != null ? !asFile.equals(that.asFile) :that.asFile != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(asFile,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/BinaryBuildSourceFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class BinaryBuildSourceFluentImpl<A extends io.fabric8.openshift.api.model.BinaryBuildSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.BinaryBuildSourceFluent<A>{
  public BinaryBuildSourceFluentImpl() {
  }
  public BinaryBuildSourceFluentImpl(io.fabric8.openshift.api.model.BinaryBuildSource instance) {
    this.withAsFile(instance.getAsFile()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String asFile;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getAsFile() {
    return this.asFile;
  }
  public A withAsFile(java.lang.String asFile) {
    this.asFile=asFile; return (A) this;
  }
  public java.lang.Boolean hasAsFile() {
    return this.asFile != null;
  }
  
  /**
   * Method is deprecated. use withAsFile instead.
   */
  @java.lang.Deprecated
  public A withNewAsFile(java.lang.String arg0) {
    return (A)withAsFile(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BinaryBuildSourceFluentImpl that = (BinaryBuildSourceFluentImpl) o;
    if (asFile != null ? !asFile.equals(that.asFile) :that.asFile != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(asFile,  additionalProperties,  super.hashCode());
  }
  
}
